==> thux.order-2.0.1.tar.gz: thux.order-2.0.1/thux/order/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('product', '__first__'),
        ('bank', '__first__'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('office', '__first__'),
        ('currency', '__first__'),
        ('store', '__first__'),
        ('organization', '__first__'),
        ('carriage', '__first__'),
        ('payment', '__first__'),
        ('vat', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.CharField(default=0, max_length=3, verbose_name='status', db_index=True, choices=[(0, 'RICEVIMENTO'), (1, 'PREPARAZIONE'), (2, 'SPEDIZIONE'), (3, 'EVASO')])),
                ('description', models.CharField(max_length=255, verbose_name='description', db_index=True)),
                ('number', models.CharField(db_index=True, max_length=50, verbose_name='number', db_column=b'pnumber', blank=True)),
                ('owner_number', models.CharField(db_index=True, max_length=50, verbose_name='ref owner number', blank=True)),
                ('date_p', models.DateField(verbose_name='date', db_index=True)),
                ('ddt_completed', models.BooleanField(default=False, db_index=True, verbose_name='DDT completed')),
                ('invoice_completed', models.BooleanField(default=False, db_index=True, verbose_name='invoice completed')),
                ('note', models.TextField(verbose_name='note', blank=True)),
                ('internal_note', models.TextField(verbose_name='internal note', blank=True)),
                ('accepted', models.BooleanField(default=False, db_index=True, verbose_name='accepted')),
                ('total_income', models.DecimalField(default=0, verbose_name='total income', max_digits=11, decimal_places=4)),
                ('total_fee', models.DecimalField(default=0, verbose_name='total fee', max_digits=11, decimal_places=4)),
                ('total_discount', models.DecimalField(default=0, verbose_name='total discount', max_digits=11, decimal_places=4)),
                ('total_vat', models.DecimalField(default=0, verbose_name='total VAT', max_digits=11, decimal_places=4)),
                ('total', models.DecimalField(default=0, verbose_name='total', max_digits=12, decimal_places=4)),
                ('other_shipping_address_owner', models.CharField(max_length=255, verbose_name='other shipping address owner', blank=True)),
                ('other_shipping_address', models.CharField(max_length=255, null=True, verbose_name='other shipping address', blank=True)),
                ('date_delivery', models.DateField(db_index=True, null=True, verbose_name='date delivery', blank=True)),
                ('quote_firm_for', models.CharField(max_length=255, null=True, verbose_name='quote firm for', blank=True)),
                ('delivery_window', models.CharField(max_length=255, null=True, verbose_name='delivery window', blank=True)),
                ('bank', models.ForeignKey(related_name='procedures', verbose_name='bank', blank=True, to='bank.Bank', null=True)),
                ('contact', models.ForeignKey(related_name='procedures', verbose_name='contact', blank=True, to='organization.Contact', null=True)),
                ('creator', models.ForeignKey(related_name='order_order_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('currency', models.ForeignKey(related_name='procedures', verbose_name='currency', to='currency.Currency')),
                ('delivery', models.ForeignKey(related_name='procedures', verbose_name='delivery', blank=True, to='carriage.Delivery', null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_order_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('office', models.ForeignKey(related_name='procedures', verbose_name='office', blank=True, to='office.Office', null=True)),
                ('owner', models.ForeignKey(related_name='owner_orders', verbose_name='bill to', to='organization.Organization')),
                ('payment_form', models.ForeignKey(related_name='procedures', verbose_name='payment form', blank=True, to='payment.PaymentForm', null=True)),
                ('recipient', models.ForeignKey(related_name='recipient_procedures', verbose_name='Ship to', blank=True, to='organization.Organization', null=True)),
                ('shipping_address', models.ForeignKey(related_name='procedures', verbose_name='shipping address', blank=True, to='organization.OrganizationAddress', null=True)),
                ('store_cause', models.ForeignKey(related_name='procedures', verbose_name='Store Cause', to='store.StoreCause')),
                ('vat', models.ForeignKey(related_name='procedures', verbose_name='vat', blank=True, to='vat.Vat', null=True)),
            ],
            options={
                'verbose_name': 'procedure',
                'verbose_name_plural': 'procedures',
            },
        ),
        migrations.CreateModel(
            name='OrderRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('quantity', models.DecimalField(default=0, verbose_name='quantity', max_digits=9, decimal_places=2)),
                ('price', models.DecimalField(default=0, verbose_name='unit price', max_digits=11, decimal_places=4)),
                ('not_apply_discount', models.BooleanField(default=False, verbose_name='no discount')),
                ('fee', models.DecimalField(default=0, verbose_name='fee', max_digits=9, decimal_places=2)),
                ('discount', models.DecimalField(default=0, verbose_name='discount', max_digits=9, decimal_places=2)),
                ('perc_discount1', models.DecimalField(default=0, verbose_name='discount 1 %', max_digits=5, decimal_places=2)),
                ('perc_discount2', models.DecimalField(default=0, verbose_name='discount 2 %', max_digits=5, decimal_places=2)),
                ('ddt_completed', models.BooleanField(db_index=True, verbose_name='DDT completed')),
                ('invoice_completed', models.BooleanField(db_index=True, verbose_name='invoice completed')),
                ('description', models.CharField(max_length=255, verbose_name='description', blank=True)),
                ('long_description', models.TextField(verbose_name='long description', blank=True)),
                ('note', models.TextField(verbose_name='note', blank=True)),
                ('to_print', models.BooleanField(default=True, db_index=True, verbose_name='to print')),
                ('date_delivery', models.DateField(db_index=True, null=True, verbose_name='date delivery', blank=True)),
                ('creator', models.ForeignKey(related_name='order_orderrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_orderrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('order', models.ForeignKey(related_name='order_rows', verbose_name='order', to='order.Order')),
                ('product', models.ForeignKey(related_name='order_rows', verbose_name='product', to='product.Product')),
                ('store_cause', models.ForeignKey(related_name='order_rows', verbose_name='Store Cause', to='store.StoreCause')),
                ('unit', models.ForeignKey(default=b'pz', verbose_name='unit', to='product.UnitType')),
                ('vat', models.ForeignKey(related_name='order_rows', verbose_name='Vat', to='vat.Vat')),
            ],
            options={
                'ordering': ('-procedure__date_p', '-procedure__number', 'ordering', 'id'),
                'verbose_name': 'procedure row',
                'verbose_name_plural': 'procedure rows',
            },
        ),
        migrations.CreateModel(
            name='VatRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('total_income', models.DecimalField(verbose_name='total income', max_digits=9, decimal_places=2)),
                ('total_fee', models.DecimalField(verbose_name='total fee', max_digits=9, decimal_places=2)),
                ('total_discount', models.DecimalField(verbose_name='total discount', max_digits=9, decimal_places=2)),
                ('total_vat', models.DecimalField(verbose_name='total vat', max_digits=9, decimal_places=2)),
                ('creator', models.ForeignKey(related_name='order_vatrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_vatrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('order', models.ForeignKey(related_name='vat_total_rows', verbose_name='order', to='order.Order')),
                ('vat', models.ForeignKey(related_name='vat_total_rows', verbose_name='vat', to='vat.Vat')),
            ],
            options={
                'ordering': ('vat__ordering', 'vat__code'),
                'verbose_name': 'vat row',
                'verbose_name_plural': 'vat rows',
            },
        ),
        migrations.AlterUniqueTogether(
            name='vatrow',
            unique_together=set([('order', 'vat')]),
        ),
    ]

==> thux.order-2.0.2.tar.gz: thux.order-2.0.2/thux/order/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('product', '__first__'),
        ('bank', '__first__'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('office', '__first__'),
        ('currency', '__first__'),
        ('store', '__first__'),
        ('organization', '__first__'),
        ('carriage', '__first__'),
        ('payment', '__first__'),
        ('vat', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.CharField(default=0, max_length=3, verbose_name='status', db_index=True, choices=[(0, 'RICEVIMENTO'), (1, 'PREPARAZIONE'), (2, 'SPEDIZIONE'), (3, 'EVASO')])),
                ('description', models.CharField(max_length=255, verbose_name='description', db_index=True)),
                ('number', models.CharField(db_index=True, max_length=50, verbose_name='number', db_column='pnumber', blank=True)),
                ('owner_number', models.CharField(db_index=True, max_length=50, verbose_name='ref owner number', blank=True)),
                ('date_p', models.DateField(verbose_name='date', db_index=True)),
                ('ddt_completed', models.BooleanField(default=False, db_index=True, verbose_name='DDT completed')),
                ('invoice_completed', models.BooleanField(default=False, db_index=True, verbose_name='invoice completed')),
                ('note', models.TextField(verbose_name='note', blank=True)),
                ('internal_note', models.TextField(verbose_name='internal note', blank=True)),
                ('accepted', models.BooleanField(default=False, db_index=True, verbose_name='accepted')),
                ('total_income', models.DecimalField(default=0, verbose_name='total income', max_digits=11, decimal_places=4)),
                ('total_fee', models.DecimalField(default=0, verbose_name='total fee', max_digits=11, decimal_places=4)),
                ('total_discount', models.DecimalField(default=0, verbose_name='total discount', max_digits=11, decimal_places=4)),
                ('total_vat', models.DecimalField(default=0, verbose_name='total VAT', max_digits=11, decimal_places=4)),
                ('total', models.DecimalField(default=0, verbose_name='total', max_digits=12, decimal_places=4)),
                ('other_shipping_address_owner', models.CharField(max_length=255, verbose_name='other shipping address owner', blank=True)),
                ('other_shipping_address', models.CharField(max_length=255, null=True, verbose_name='other shipping address', blank=True)),
                ('date_delivery', models.DateField(db_index=True, null=True, verbose_name='date delivery', blank=True)),
                ('quote_firm_for', models.CharField(max_length=255, null=True, verbose_name='quote firm for', blank=True)),
                ('delivery_window', models.CharField(max_length=255, null=True, verbose_name='delivery window', blank=True)),
                ('bank', models.ForeignKey(related_name='procedures', verbose_name='bank', blank=True, to='bank.Bank', null=True)),
                ('contact', models.ForeignKey(related_name='procedures', verbose_name='contact', blank=True, to='organization.Contact', null=True)),
                ('creator', models.ForeignKey(related_name='order_order_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('currency', models.ForeignKey(related_name='procedures', verbose_name='currency', to='currency.Currency')),
                ('delivery', models.ForeignKey(related_name='procedures', verbose_name='delivery', blank=True, to='carriage.Delivery', null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_order_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('office', models.ForeignKey(related_name='procedures', verbose_name='office', blank=True, to='office.Office', null=True)),
                ('owner', models.ForeignKey(related_name='owner_orders', verbose_name='bill to', to='organization.Organization')),
                ('payment_form', models.ForeignKey(related_name='procedures', verbose_name='payment form', blank=True, to='payment.PaymentForm', null=True)),
                ('recipient', models.ForeignKey(related_name='recipient_procedures', verbose_name='Ship to', blank=True, to='organization.Organization', null=True)),
                ('shipping_address', models.ForeignKey(related_name='procedures', verbose_name='shipping address', blank=True, to='organization.OrganizationAddress', null=True)),
                ('store_cause', models.ForeignKey(related_name='procedures', verbose_name='Store Cause', to='store.StoreCause')),
                ('vat', models.ForeignKey(related_name='procedures', verbose_name='vat', blank=True, to='vat.Vat', null=True)),
            ],
            options={
                'verbose_name': 'procedure',
                'verbose_name_plural': 'procedures',
            },
        ),
        migrations.CreateModel(
            name='OrderRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('quantity', models.DecimalField(default=0, verbose_name='quantity', max_digits=9, decimal_places=2)),
                ('price', models.DecimalField(default=0, verbose_name='unit price', max_digits=11, decimal_places=4)),
                ('not_apply_discount', models.BooleanField(default=False, verbose_name='no discount')),
                ('fee', models.DecimalField(default=0, verbose_name='fee', max_digits=9, decimal_places=2)),
                ('discount', models.DecimalField(default=0, verbose_name='discount', max_digits=9, decimal_places=2)),
                ('perc_discount1', models.DecimalField(default=0, verbose_name='discount 1 %', max_digits=5, decimal_places=2)),
                ('perc_discount2', models.DecimalField(default=0, verbose_name='discount 2 %', max_digits=5, decimal_places=2)),
                ('ddt_completed', models.BooleanField(db_index=True, verbose_name='DDT completed')),
                ('invoice_completed', models.BooleanField(db_index=True, verbose_name='invoice completed')),
                ('description', models.CharField(max_length=255, verbose_name='description', blank=True)),
                ('long_description', models.TextField(verbose_name='long description', blank=True)),
                ('note', models.TextField(verbose_name='note', blank=True)),
                ('to_print', models.BooleanField(default=True, db_index=True, verbose_name='to print')),
                ('date_delivery', models.DateField(db_index=True, null=True, verbose_name='date delivery', blank=True)),
                ('creator', models.ForeignKey(related_name='order_orderrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_orderrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('order', models.ForeignKey(related_name='order_rows', verbose_name='order', to='order.Order')),
                ('product', models.ForeignKey(related_name='order_rows', verbose_name='product', to='product.Product')),
                ('store_cause', models.ForeignKey(related_name='order_rows', verbose_name='Store Cause', to='store.StoreCause')),
                ('unit', models.ForeignKey(default='pz', verbose_name='unit', to='product.UnitType')),
                ('vat', models.ForeignKey(related_name='order_rows', verbose_name='Vat', to='vat.Vat')),
            ],
            options={
                'ordering': ('-procedure__date_p', '-procedure__number', 'ordering', 'id'),
                'verbose_name': 'procedure row',
                'verbose_name_plural': 'procedure rows',
            },
        ),
        migrations.CreateModel(
            name='VatRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('total_income', models.DecimalField(verbose_name='total income', max_digits=9, decimal_places=2)),
                ('total_fee', models.DecimalField(verbose_name='total fee', max_digits=9, decimal_places=2)),
                ('total_discount', models.DecimalField(verbose_name='total discount', max_digits=9, decimal_places=2)),
                ('total_vat', models.DecimalField(verbose_name='total vat', max_digits=9, decimal_places=2)),
                ('creator', models.ForeignKey(related_name='order_vatrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_vatrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('order', models.ForeignKey(related_name='vat_total_rows', verbose_name='order', to='order.Order')),
                ('vat', models.ForeignKey(related_name='vat_total_rows', verbose_name='vat', to='vat.Vat')),
            ],
            options={
                'ordering': ('vat__ordering', 'vat__code'),
                'verbose_name': 'vat row',
                'verbose_name_plural': 'vat rows',
            },
        ),
        migrations.AlterUniqueTogether(
            name='vatrow',
            unique_together=set([('order', 'vat')]),
        ),
    ]
